@@ -2,20 +2,22 @@
 
 """
 Wherever smart people work, doors are unlocked. -- Steve Wozniak
-
 """
 
 __title__ = 'newspaper'
-__version__ = '0.0.1'
 __author__ = 'Lucas Ou-Yang'
 __license__ = 'MIT'
-__copyright__ = 'Copyright 2014 Lucas Ou-Yang'
+__copyright__ = 'Copyright 2014, Lucas Ou-Yang'
 
-from . import utils
 from .article import Article, ArticleException
 from .source import Source
+
 from .api import build, build_article, popular_urls, hot
-from .settings import VERSION
+from .api import NewsPool, Configuration as Config
+
+news_pool = NewsPool()
+
+from .version import __version__
 
 # Set default logging handler to avoid "No handler found" warnings.
 import logging
